@@ -8,6 +8,8 @@ from .api.resources.transaction_resource import (
 )
 from .api.resources.accounts_resources import APIAccounts
 from .api.resources.company_resources import APICompany
+from .api.resources.export_resources import APIExports
+from .api.resources.metric_resources import APIMetrics
 
 
 class Rehive:
@@ -30,3 +32,5 @@ class Rehive:
         self.transaction_collections = APITransactionCollections(self.client)
         self.accounts = APIAccounts(self.client)
         self.company = APICompany(self.client)
+        self.exports = APIExports(self.client)
+        self.metrics = APIMetrics(self.client)
